@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Mouse;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use IO::Socket::INET;
 use IO::Socket::UNIX;
@@ -281,13 +281,14 @@ sub _write {
         my $nwrite
             = $self->socket_io->syswrite($data, $self->write_length, $written);
 
-        unless ($nwrite) {
+        if (!$nwrite) {
             if ($retry > $self->max_write_retry) {
                 die "failed write retry; max write retry count. $!";
             }
             $retry++;
+        } else {
+            $written += $nwrite;
         }
-        $written += $nwrite;
     }
     $written;
 }
